@@ -1,5 +1,5 @@
+from . import style
 from .figure import figure
-#from .theme import theme
 
 import sys
 import os
