@@ -4,13 +4,16 @@ import seaborn as sns
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 
+dirname = os.path.dirname(os.path.realpath(__file__))
+
 # Set base theme
 sns.set()
 sns.set_style("ticks")
 
 # Use custom font
 dirname = os.path.dirname(os.path.realpath(__file__))
-font_files = mpl.font_manager.findSystemFonts(fontpaths=dirname + "/fonts/")
+font_files = mpl.font_manager.findSystemFonts(
+    fontpaths="file:"+dirname + "/fonts/")
 font_files = list(sorted(font_files))
 for font_file in font_files:
     mpl.font_manager.fontManager.addfont(font_file)
@@ -47,10 +50,10 @@ colours = [base, "#2d4eeb", "#eb2d2d", "#2deb6c",
 mpl.rcParams['axes.prop_cycle'] = mpl.cycler(color=colours)
 
 # Image
-# images = {
-#     'normal':   plt.imread(dirname + '/images/halfspace.png'),
-#     'inverted': plt.imread(dirname + '/images/halfspace_inverted.png')
-# }
+images = {
+    'normal':   plt.imread("file:" + dirname + '/images/halfspace.png'),
+    'inverted': plt.imread("file:" + dirname + '/images/halfspace_inverted.png')
+}
 pad = 10
 # images = {key: im[85 - pad:165 + pad, 85 - pad:435 + pad, :]
 #           for key, im in images.items()}
